# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import pydantic_v1


class StsTransferApi(pydantic_v1.BaseModel):
    aws_access_key_id: str = pydantic_v1.Field()
    """
    AWS access key.
    """

    aws_secret_access_key: str = pydantic_v1.Field()
    """
    AWS secret accesss key.
    """

    aws_session_token: typing.Optional[str] = None
    s3bucket: str = pydantic_v1.Field(alias="s3_bucket")
    """
    S3 bucket.
    """

    s3endpoint_url: typing.Optional[str] = pydantic_v1.Field(alias="s3_endpoint_url", default=None)
    s3key: str = pydantic_v1.Field(alias="s3_key")
    """
    S3 key.
    """

    s3url: str = pydantic_v1.Field(alias="s3_url")
    """
    S3 full URL.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
