# This file was auto-generated by Fern from our API Definition.

import typing

BaseEngine = typing.Union[
    typing.Literal[
        "text/llama-2-7b",
        "text/llama-2-13b-chat",
        "text/llama-2-70b-chat",
        "text/codellama-7b-instruct",
        "text/codellama-13b-instruct",
        "text/codellama-34b-instruct",
        "text/mistral-7b-instruct",
        "text/mixtral-8x7b-instruct",
        "image/controlnet-sd15",
        "image/controlnet-sdxl",
        "image/stable-diffusion-v1-5",
        "image/stable-diffusion-xl-v1-0",
        "image/stable-diffusion-ssd",
        "audio/tortoise-tts",
        "audio/rvc",
    ],
    typing.Any,
]
