# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .lora_tune import LoraTune
from .text_to_speech_latent_tune import TextToSpeechLatentTune


class Details_LoraTune(LoraTune):
    tune_type: typing.Literal["lora_tune"] = "lora_tune"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class Details_TextToSpeechLatentTune(TextToSpeechLatentTune):
    tune_type: typing.Literal["text_to_speech_latent_tune"] = "text_to_speech_latent_tune"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


Details = typing.Union[Details_LoraTune, Details_TextToSpeechLatentTune]
