# This file was auto-generated by Fern from our API Definition.

import typing

Scheduler = typing.Union[
    typing.Literal[
        "PNDM",
        "LMS",
        "KLMS",
        "DDIM",
        "DDPM",
        "HEUN",
        "K_HEUN",
        "K_EULER",
        "K_EULER_ANCESTRAL",
        "DPM_SOLVER_MULTISTEP",
        "DPM_PLUS_PLUS_2M_KARRAS",
        "DPM_SINGLE",
        "DPM_2",
        "DPM_2_ANCESTRAL",
        "DPM_PLUS_PLUS_SDE_KARRAS",
        "UNI_PC",
        "LCM",
    ],
    typing.Any,
]
