# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .lora_tune import LoraTune
from .text_to_speech_latent_tune import TextToSpeechLatentTune


class TuneDetails_LoraTune(LoraTune):
    tune_type: typing.Literal["lora_tune"] = "lora_tune"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TuneDetails_TextToSpeechLatentTune(TextToSpeechLatentTune):
    tune_type: typing.Literal["text_to_speech_latent_tune"] = "text_to_speech_latent_tune"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TuneDetails = typing.Union[TuneDetails_LoraTune, TuneDetails_TextToSpeechLatentTune]
