# This file was auto-generated by Fern from our API Definition.

import typing

TuneType = typing.Union[
    typing.Literal[
        "lora_tune", "text_to_speech_latent_tune", "text_to_speech_rvc_tune", "text_to_speech_tortoise_tune"
    ],
    typing.Any,
]
