# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import pydantic_v1
from .asset_type import AssetType
from .data import Data
from .file_structure import FileStructure
from .status import Status


class Asset(pydantic_v1.BaseModel):
    asset_type: AssetType = pydantic_v1.Field()
    """
    Asset type.
    """

    created_at: str = pydantic_v1.Field()
    """
    Asset creation time.
    """

    data: Data = pydantic_v1.Field()
    """
    Asset data.
    """

    description: str = pydantic_v1.Field()
    """
    Description.
    """

    file_structure: typing.Optional[FileStructure] = pydantic_v1.Field(default=None)
    """
    File structure.
    """

    hf_repo: typing.Optional[str] = None
    id: str = pydantic_v1.Field()
    """
    Asset id.
    """

    is_public: typing.Optional[bool] = pydantic_v1.Field(default=None)
    """
    True if asset is public.
    """

    name: str = pydantic_v1.Field()
    """
    Asset name.
    """

    size_bytes: int = pydantic_v1.Field()
    """
    Size in bytes.
    """

    status: Status = pydantic_v1.Field()
    """
    Asset status.
    """

    status_details: str = pydantic_v1.Field()
    """
    Asset status.
    """

    status_info: typing.Optional[typing.Dict[str, typing.Any]] = pydantic_v1.Field(default=None)
    """
    Asset status info.
    """

    tenant_uuid: str = pydantic_v1.Field()
    """
    Asset tenant ID.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
