# This file was auto-generated by Fern from our API Definition.

import typing

SdxlStyles = typing.Union[
    typing.Literal[
        "base",
        "3d-model",
        "analog-film",
        "anime",
        "cinematic",
        "comic-book",
        "Craft Clay",
        "modeling-compound",
        "digital-art",
        "enhance",
        "fantasy-art",
        "isometric",
        "line-art",
        "low-poly",
        "neon-punk",
        "origami",
        "photographic",
        "pixel-art",
        "tile-texture",
        "Advertising",
        "Food Photography",
        "Real Estate",
        "Abstract",
        "Cubist",
        "Graffiti",
        "Hyperrealism",
        "Impressionist",
        "Pointillism",
        "Pop Art",
        "Psychedelic",
        "Renaissance",
        "Steampunk",
        "Surrealist",
        "Typography",
        "Watercolor",
        "Fighting Game",
        "GTA",
        "Super Mario",
        "Minecraft",
        "Pokémon",
        "Retro Arcade",
        "Retro Game",
        "RPG Fantasy Game",
        "Strategy Game",
        "Street Fighter",
        "Legend of Zelda",
        "Architectural",
        "Disco",
        "Dreamscape",
        "Dystopian",
        "Fairy Tale",
        "Gothic",
        "Grunge",
        "Horror",
        "Minimalist",
        "Monochrome",
        "Nautical",
        "Space",
        "Stained Glass",
        "Techwear Fashion",
        "Tribal",
        "Zentangle",
        "Collage",
        "Flat Papercut",
        "Kirigami",
        "Paper Mache",
        "Paper Quilling",
        "Papercut Collage",
        "Papercut Shadow Box",
        "Stacked Papercut",
        "Thick Layered Papercut",
        "Alien",
        "Film Noir",
        "HDR",
        "Long Exposure",
        "Neon Noir",
        "Silhouette",
        "Tilt-Shift",
    ],
    typing.Any,
]
